/*
Shared defines for DBus interfaces and API versions to
make sure the server and client agree.

Copyright 2009 Canonical Ltd.

Authors:
    Ted Gould <ted@canonical.com>

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
version 3.0 as published by the Free Software Foundation.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License version 3.0 for more details.

You should have received a copy of the GNU General Public
License along with this library. If not, see
<http://www.gnu.org/licenses/>.
*/

#define  INDICATOR_SERVICE_INTERFACE   "org.ayatana.indicator.service"
#define  INDICATOR_SERVICE_OBJECT      "/org/ayatana/indicator/service"

#define  INDICATOR_SERVICE_VERSION     1

